@@ -14,11 +14,11 @@ use Convert::TBX::UTX qw(utx2min min2utx);
 sub convert_utx {
 	my ($self, $data) = @_;
 	my $converted = utx2min(\$data);
-	return $converted;
+	return $$converted;
 }
 
 sub convert_tbx {
 	my ($self, $data) = @_;
 	my $converted = min2utx(\$data);
-	return $converted;
+	return $$converted;
 }
